## AIS Python Components

This directory includes the AIStore Python package containing the SDK, PyTorch integration, and Botocore patch. 
See the README files in each directory in `aistore` for usage details.

- [SDK](aistore/sdk/README.md)
- [PyTorch](aistore/pytorch/README.md)
- [Botocore](aistore/botocore_patch/README.md)

## References

* [AIStore GitHub](https://github.com/NVIDIA/aistore)
* [Documentation](https://aiatscale.org/docs)
* [AIStore pip package](https://pypi.org/project/aistore/)
* [Videos and demos](https://github.com/NVIDIA/aistore/blob/master/docs/videos.md)
